Installing ms3 — ms3 0.1.2.post0.dev2+g9d887e1.dirty documentation

# Installing ms3

The library is hosted at PyPI and can be installed via `pip`.

## Unix-based systems

Open up your console / command-line terminal and make sure to enter the Python 3 environment where you want to install the library. You can check which Python executable is currently used by typing

    which python

### Using Python >= 3.6

Check the Python of your environment by typing

    python -V

If it’s a Python 2 version, replace `python` by `python3`:

    which python3
    python3 -V

If Python 3 doesn’t seem to be installed, we recommend installing it via the small Miniconda or the large Anaconda. The latter comes with many libraries pre-installed, e.g. Jupyter notebooks.

### Installing via `pip`

First, update your package manager

    python3 -m pip install –-upgrade pip

Then you’re ready to install ms3:

    python3 -m pip install ms3